@@ -16,7 +16,9 @@
  */
 package org.apache.commons.text;
 
+import java.util.Collections;
 import java.util.Map;
+import java.util.Objects;
 import java.util.ResourceBundle;
 
 import org.apache.commons.text.lookup.StringLookup;
@@ -27,12 +29,15 @@ import org.apache.commons.text.lookup.StringLookupFactory;
  * <p>
  * This class represents the simplest form of a string to string map. It has a benefit over a map in that it can create
  * the result on demand based on the key.
+ * </p>
  * <p>
  * This class comes complete with various factory methods. If these do not suffice, you can subclass and implement your
  * own matcher.
+ * </p>
  * <p>
  * For example, it would be possible to implement a lookup that used the key as a primary key, and looked up the value
  * on demand from the database
+ * </p>
  *
  * @param <V> the type of the values supported by the lookup
  * @since 1.0
@@ -41,76 +46,6 @@ import org.apache.commons.text.lookup.StringLookupFactory;
 @Deprecated
 public abstract class StrLookup<V> implements StringLookup {
 
-    /**
-     * Lookup that always returns null.
-     */
-    private static final StrLookup<String> NONE_LOOKUP = new MapStrLookup<>(null);
-
-    /**
-     * Lookup based on system properties.
-     */
-    private static final StrLookup<String> SYSTEM_PROPERTIES_LOOKUP = new SystemPropertiesStrLookup();
-
-    // -----------------------------------------------------------------------
-    /**
-     * Returns a lookup which always returns null.
-     *
-     * @return a lookup that always returns null, not null
-     */
-    public static StrLookup<?> noneLookup() {
-        return NONE_LOOKUP;
-    }
-
-    /**
-     * Returns a new lookup which uses a copy of the current {@link System#getProperties() System properties}.
-     * <p>
-     * If a security manager blocked access to system properties, then null will be returned from every lookup.
-     * <p>
-     * If a null key is used, this lookup will throw a NullPointerException.
-     *
-     * @return a lookup using system properties, not null
-     */
-    public static StrLookup<String> systemPropertiesLookup() {
-        return SYSTEM_PROPERTIES_LOOKUP;
-    }
-
-    /**
-     * Returns a lookup which looks up values using a map.
-     * <p>
-     * If the map is null, then null will be returned from every lookup. The map result object is converted to a string
-     * using toString().
-     *
-     * @param <V> the type of the values supported by the lookup
-     * @param map the map of keys to values, may be null
-     * @return a lookup using the map, not null
-     */
-    public static <V> StrLookup<V> mapLookup(final Map<String, V> map) {
-        return new MapStrLookup<>(map);
-    }
-
-    /**
-     * Returns a lookup which looks up values using a ResourceBundle.
-     * <p>
-     * If the ResourceBundle is null, then null will be returned from every lookup. The map result object is converted
-     * to a string using toString().
-     *
-     * @param resourceBundle the map of keys to values, may be null
-     * @return a lookup using the map, not null
-     * @see StringLookupFactory#resourceBundleStringLookup(String)
-     */
-    public static StrLookup<String> resourceBundleLookup(final ResourceBundle resourceBundle) {
-        return new ResourceBundleLookup(resourceBundle);
-    }
-
-    // -----------------------------------------------------------------------
-    /**
-     * Constructor.
-     */
-    protected StrLookup() {
-        super();
-    }
-
-    // -----------------------------------------------------------------------
     /**
      * Lookup implementation that uses a Map.
      *
@@ -127,27 +62,21 @@ public abstract class StrLookup<V> implements StringLookup {
          * @param map the map of keys to values, may be null
          */
         MapStrLookup(final Map<String, V> map) {
-            this.map = map;
+            this.map = map != null ? map : Collections.emptyMap();
         }
 
         /**
          * Looks up a String key to a String value using the map.
          * <p>
          * If the map is null, then null is returned. The map result object is converted to a string using toString().
+         * </p>
          *
          * @param key the key to be looked up, may be null
-         * @return the matching value, null if no match
+         * @return The matching value, null if no match
          */
         @Override
         public String lookup(final String key) {
-            if (map == null) {
-                return null;
-            }
-            final Object obj = map.get(key);
-            if (obj == null) {
-                return null;
-            }
-            return obj.toString();
+            return Objects.toString(map.get(key), null);
         }
 
         @Override
@@ -156,7 +85,6 @@ public abstract class StrLookup<V> implements StringLookup {
         }
     }
 
-    // -----------------------------------------------------------------------
     /**
      * Lookup implementation based on a ResourceBundle.
      */
@@ -189,7 +117,6 @@ public abstract class StrLookup<V> implements StringLookup {
 
     }
 
-    // -----------------------------------------------------------------------
     /**
      * Lookup implementation based on system properties.
      */
@@ -199,15 +126,84 @@ public abstract class StrLookup<V> implements StringLookup {
          */
         @Override
         public String lookup(final String key) {
-            if (key.length() > 0) {
+            if (!key.isEmpty()) {
                 try {
                     return System.getProperty(key);
-                } catch (final SecurityException scex) {
-                    // Squelched. All lookup(String) will return null.
-                    return null;
+                } catch (final SecurityException ignored) {
+                    // Noop: All lookup(String) will return null.
                 }
             }
             return null;
         }
     }
+
+    /**
+     * Lookup that always returns null.
+     */
+    private static final StrLookup<String> NONE_LOOKUP = new MapStrLookup<>(null);
+
+    /**
+     * Lookup based on system properties.
+     */
+    private static final StrLookup<String> SYSTEM_PROPERTIES_LOOKUP = new SystemPropertiesStrLookup();
+
+    /**
+     * Returns a lookup which looks up values using a map.
+     * <p>
+     * If the map is null, then null will be returned from every lookup. The map result object is converted to a string
+     * using toString().
+     * </p>
+     *
+     * @param <V> the type of the values supported by the lookup
+     * @param map the map of keys to values, may be null
+     * @return a lookup using the map, not null
+     */
+    public static <V> StrLookup<V> mapLookup(final Map<String, V> map) {
+        return new MapStrLookup<>(map);
+    }
+
+    /**
+     * Returns a lookup which always returns null.
+     *
+     * @return a lookup that always returns null, not null
+     */
+    public static StrLookup<?> noneLookup() {
+        return NONE_LOOKUP;
+    }
+
+    /**
+     * Returns a lookup which looks up values using a ResourceBundle.
+     * <p>
+     * If the ResourceBundle is null, then null will be returned from every lookup. The map result object is converted
+     * to a string using toString().
+     * </p>
+     *
+     * @param resourceBundle the map of keys to values, may be null
+     * @return a lookup using the map, not null
+     * @see StringLookupFactory#resourceBundleStringLookup(String)
+     */
+    public static StrLookup<String> resourceBundleLookup(final ResourceBundle resourceBundle) {
+        return new ResourceBundleLookup(resourceBundle);
+    }
+
+    /**
+     * Returns a new lookup which uses a copy of the current {@link System#getProperties() System properties}.
+     * <p>
+     * If a security manager blocked access to system properties, then null will be returned from every lookup.
+     * </p>
+     * <p>
+     * If a null key is used, this lookup will throw a NullPointerException.
+     * </p>
+     *
+     * @return a lookup using system properties, not null
+     */
+    public static StrLookup<String> systemPropertiesLookup() {
+        return SYSTEM_PROPERTIES_LOOKUP;
+    }
+
+    /**
+     * Constructor.
+     */
+    protected StrLookup() {
+    }
 }
